unofficial mirror of emacs-devel@gnu.org 
 help / color / mirror / code / Atom feed
From: Ted Zlatanov <tzz@lifelogs.com>
Subject: Re: Add M-x occur to the menu-bar
Date: Mon, 09 Feb 2004 13:43:28 -0500	[thread overview]
Message-ID: <4n8yjcccvj.fsf@collins.bwh.harvard.edu> (raw)
In-Reply-To: m3fzdnsqv3.fsf@kfs-l.imdomain.dk

[-- Attachment #1: Type: text/plain, Size: 1210 bytes --]

On 07 Feb 2004, storm@cua.dk wrote:

> I haven't thought a lot about it, but I don't understand why you
> need that extra allow-with-next-error-function arg to
> compilation-buffer-p and compilation-find-buffer.

I was trying to draw a distinction between "find a compilation
buffer" in compile.el and "find a buffer where next-error will
work."  I'll leave it without that distinction for now, and I
don't think it will make a difference (based on my understanding
of the code).

> Can you mention the commands where is that behaviour NOT desireable,
> and why?

I was trying to preserve the *meaning* of compilation-find-buffer,
by making it select an Occur buffer only if specifically
requested.

> For the last four lines, you can just write
> 
>         (and allow-with-next-error-function
>              compilation-next-error-function)
> 
> as you already did a (set-buffer buffer), so there's no reason to
> use buffer-local-value here.

I originally had that code in replace.el, where I didn't want to
rely on the existence of the compilation-next-error-function
symbol.  My mistake.

> You no longer need the occur-last-buffer variable.

Done.

Attached is latest patch.  Thanks for your help.

Ted


[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: next-error+occur.patch --]
[-- Type: text/x-patch, Size: 5141 bytes --]

--- /opt/local-csw/encap/emacs-cvs/share/emacs/21.3.50/lisp/replace.el	Mon Feb  2 09:23:00 2004
+++ /home/tzz/emacs/mine/replace.el	Mon Feb  9 13:36:30 2004
@@ -614,6 +614,19 @@
   "Move to the Nth (default 1) previous match in an Occur mode buffer."
   (interactive "p")
   (occur-find-match n #'previous-single-property-change "No earlier matches"))
+
+(defun occur-next-error (&optional argp)
+  "Move to the Nth (default 1) next match in an Occur mode buffer.
+Compatibility function for \\[next-error] invocations."
+  (interactive "p")
+  (occur-find-match
+   (prefix-numeric-value argp)
+   (if (> 0 (prefix-numeric-value argp))
+       #'previous-single-property-change
+     #'next-single-property-change)
+   "No more matches")
+  (occur-mode-goto-occurrence))
+
 \f
 (defcustom list-matching-lines-default-context-lines 0
   "*Default number of context lines included around `list-matching-lines' matches.
@@ -800,7 +813,10 @@
 	(setq occur-revert-arguments (list regexp nlines bufs)
 	      buffer-read-only t)
 	(if (> count 0)
-	    (display-buffer occur-buf)
+	    (progn
+	      (display-buffer occur-buf)
+	      (setq compilation-last-buffer occur-buf)
+	      (setq compilation-next-error-function 'occur-next-error))
 	  (kill-buffer occur-buf)))
       (run-hooks 'occur-hook))))
 

[-- Attachment #3: Type: text/plain, Size: 141 bytes --]

_______________________________________________
Emacs-devel mailing list
Emacs-devel@gnu.org
http://mail.gnu.org/mailman/listinfo/emacs-devel

  parent reply	other threads:[~2004-02-09 18:43 UTC|newest]

Thread overview: 101+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2003-09-12 16:07 Add M-x occur to the menu-bar Marshall, Simon
2003-09-13  9:36 ` Eli Zaretskii
2003-09-13 13:57 ` Richard Stallman
2003-09-18 17:21   ` Kevin Rodgers
2003-09-18 18:40     ` Miles Bader
2003-09-21 12:11       ` Eli Zaretskii
2003-09-21 11:28         ` Miles Bader
2003-09-21 13:55       ` Ehud Karni
2003-09-19 12:22     ` Richard Stallman
2003-09-18 17:10 ` Kevin Rodgers
2003-09-18 17:27   ` Masatake YAMATO
2004-01-27 15:34   ` Ted Zlatanov
2004-01-27 17:24     ` Benjamin Rutt
2004-01-27 18:46       ` Ted Zlatanov
2004-01-27 19:02         ` Benjamin Rutt
2004-01-27 19:04       ` Stefan Monnier
2004-01-27 19:35         ` Ted Zlatanov
2004-01-27 23:03           ` Miles Bader
2004-01-28  3:53             ` Ted Zlatanov
2004-01-28 14:30               ` Stefan Monnier
2004-01-28 15:46                 ` Ted Zlatanov
2004-01-28 22:45                   ` Kevin Rodgers
2004-01-29  5:42                     ` Eli Zaretskii
2004-01-29 15:19                       ` Stefan Monnier
2004-01-29 15:28                         ` Miles Bader
2004-01-29 15:41                           ` David Kastrup
2004-01-29 20:52                         ` Kai Grossjohann
2004-01-29 17:51                 ` Richard Stallman
2004-01-30 19:00                   ` Ted Zlatanov
2004-02-04 20:39                     ` Ted Zlatanov
2004-02-04 23:20                       ` Kim F. Storm
2004-02-05 17:27                         ` Ted Zlatanov
2004-02-06 23:57                           ` Kim F. Storm
2004-02-06 23:10                             ` Stefan Monnier
2004-02-07  0:52                               ` David Kastrup
2004-02-07 22:39                                 ` Stefan Monnier
2004-02-09 18:44                               ` Ted Zlatanov
2004-02-09 18:43                             ` Ted Zlatanov [this message]
2004-02-10 12:44                               ` Richard Stallman
2004-02-10 14:50                                 ` Kim F. Storm
2004-02-10 16:51                                   ` Ted Zlatanov
2004-02-12 14:57                                   ` Richard Stallman
2004-02-12 16:46                                     ` Ted Zlatanov
2004-02-12 19:48                                       ` Stefan Monnier
2004-02-12 20:34                                         ` Ted Zlatanov
2004-02-12 20:57                                           ` Stefan Monnier
2004-02-13 20:58                                             ` Andreas Schwab
2004-02-13 21:04                                               ` Stefan Monnier
2004-02-14 17:17                                               ` Richard Stallman
2004-02-12 23:19                                           ` Kim F. Storm
2004-02-14 17:15                                             ` Richard Stallman
2004-02-13 17:03                                       ` Ted Zlatanov
2004-02-13 21:47                                         ` Kim F. Storm
2004-02-14 17:16                                         ` Richard Stallman
2004-02-23 20:18                                       ` Ted Zlatanov
2004-02-25 13:24                                         ` Richard Stallman
2004-02-23 20:33                                       ` Ted Zlatanov
2004-02-24  0:37                                         ` Kim F. Storm
2004-02-24 17:23                                           ` Ted Zlatanov
     [not found]                                       ` <jwvr7x06q95.fsf-monnier+emacs <E1Avz1R-0001M2-Df@fencepost.gnu.org>
     [not found]                                         ` <4n1xohpsvt.fsf@collins.bwh.harvard.edu>
     [not found]                                         ` <4n8yikpjcz.fsf@collins.bwh.harvard.edu>
2004-03-02 15:51                                           ` Richard Stallman
2004-03-02 17:30                                             ` Ted Zlatanov
2004-03-03  1:40                                               ` Miles Bader
2004-03-03 20:41                                                 ` Mike Hearn
2004-03-03 21:57                                                 ` Kim F. Storm
2004-03-07 16:04                                                   ` Richard Stallman
2004-03-03 15:19                                               ` Richard Stallman
2004-03-08 20:20                                           ` Ted Zlatanov
2004-03-02 23:25                                       ` Kevin Rodgers
2004-03-03 13:27                                         ` Stefan Monnier
2004-03-04 16:41                                         ` Richard Stallman
2004-03-05 18:14                                       ` Ted Zlatanov
2004-03-11 20:19                                         ` Richard Stallman
2004-03-14  2:04                                           ` Kim F. Storm
2004-03-25  5:31                                       ` Ted Zlatanov
2004-03-25 10:01                                         ` Kim F. Storm
2004-03-25 16:24                                         ` Stefan Monnier
2004-04-07 21:01                                       ` Ted Zlatanov
2004-04-07 21:50                                         ` Stefan Monnier
2004-04-08 14:57                                         ` Richard Stallman
2004-04-14  3:28                                       ` Ted Zlatanov
2004-04-14 17:57                                       ` Ted Zlatanov
2004-04-15  0:20                                         ` Kim F. Storm
2004-04-15  1:29                                           ` Kim F. Storm
2004-04-15 16:44                                         ` Richard Stallman
2004-04-14 18:04                                       ` Ted Zlatanov
2004-04-14 21:57                                         ` Stefan Monnier
2004-04-15 15:40                                       ` Ted Zlatanov
2004-04-15 15:59                                       ` Ted Zlatanov
2004-04-15 18:43                                       ` Ted Zlatanov
2004-02-07  9:00                           ` Richard Stallman
2004-01-28  9:04     ` Richard Stallman
  -- strict thread matches above, loose matches on Subject: below --
2003-09-19  9:10 Marshall, Simon
2003-09-20  7:49 ` Richard Stallman
2003-09-23  1:06   ` Miles Bader
2003-09-23 18:50     ` Eli Zaretskii
2003-09-23 20:10       ` David Kastrup
2003-09-24  8:40       ` Richard Stallman
2003-09-16  8:30 Marshall, Simon
2003-09-17 18:02 ` Richard Stallman
2003-09-16  8:16 Marshall, Simon
2003-09-11 16:11 Marshall, Simon

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://www.gnu.org/software/emacs/

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=4n8yjcccvj.fsf@collins.bwh.harvard.edu \
    --to=tzz@lifelogs.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
--- /opt/local-csw/encap/emacs-cvs/share/emacs/21.3.50/lisp/progmodes/compile.el	Sat Jan  3 17:38:03 2004
+++ /home/tzz/emacs/mine/compile.el	Mon Feb  9 13:35:00 2004
@@ -36,7 +36,6 @@
   :group 'tools
   :group 'processes)
 
-
 ;;;###autoload
 (defcustom compilation-mode-hook nil
   "*List of hook functions run by `compilation-mode' (see `run-hooks')."
@@ -133,6 +132,15 @@
 A buffer becomes most recent when its compilation is started
 or when it is used with \\[next-error] or \\[compile-goto-error].")
 
+(defvar compilation-next-error-function nil
+  "The next-error analogue for other modes.
+This variable can be bound to a function by a mode.  It is
+buffer-local by default.  Together with
+`compilation-last-buffer', this variable lets modes hook into
+\\[next-error].")
+
+(make-variable-buffer-local 'compilation-next-error-function)
+
 (defvar compilation-in-progress nil
   "List of compilation processes now running.")
 (or (assq 'compilation-in-progress minor-mode-alist)
@@ -1057,10 +1065,12 @@
     errors))
 
 (defsubst compilation-buffer-p (buffer)
-  (save-excursion
-    (set-buffer buffer)
-    (or compilation-shell-minor-mode compilation-minor-mode
-	(eq major-mode 'compilation-mode))))
+  "Test if BUFFER is a compilation buffer."
+  (with-current-buffer buffer
+    (or compilation-shell-minor-mode 
+	compilation-minor-mode
+	(eq major-mode 'compilation-mode)
+	compilation-next-error-function)))
 
 (defun compilation-next-error (n)
   "Move point to the next error in the compilation buffer.
@@ -1406,12 +1416,14 @@
 Just \\[universal-argument] as a prefix means reparse the error message buffer
 and start at the first error.
 
-\\[next-error] normally uses the most recently started compilation or
-grep buffer.  However, it can operate on any buffer with output from
-the \\[compile] and \\[grep] commands, or, more generally, on any
-buffer in Compilation mode or with Compilation Minor mode enabled.  To
-specify use of a particular buffer for error messages, type
-\\[next-error] in that buffer.
+\\[next-error] normally uses the most recently started
+compilation or grep buffer.  However, it can operate on any
+buffer with output from the \\[compile], \\[grep] commands, or,
+more generally, on any buffer in Compilation mode or with
+Compilation Minor mode enabled, or any buffer in which
+`compilation-next-error-function' is bound to an appropriate
+function.  To specify use of a particular buffer for error
+messages, type \\[next-error] in that buffer.
 
 Once \\[next-error] has chosen the buffer for error messages,
 it stays with that buffer until you use it in some other buffer which
@@ -1421,13 +1433,23 @@
 \`compilation-error-regexp-alist' for customization ideas."
   (interactive "P")
   (setq compilation-last-buffer (compilation-find-buffer))
-  (compilation-goto-locus (compilation-next-error-locus
-			   ;; We want to pass a number here only if
-			   ;; we got a numeric prefix arg, not just C-u.
-			   (and (not (consp argp))
-				(prefix-numeric-value argp))
-			   (consp argp))))
+  (if (buffer-local-value 
+       'compilation-next-error-function 
+       compilation-last-buffer)
+      ;; do the right thing for modes that bind compilation-next-error-function
+      (progn
+	(set-buffer compilation-last-buffer)
+	(funcall compilation-next-error-function argp))
+    (compilation-goto-locus (compilation-next-error-locus
+			     ;; We want to pass a number here only if
+			     ;; we got a numeric prefix arg, not just C-u.
+			     (and (not (consp argp))
+				  (prefix-numeric-value argp))
+			     (consp argp)))))
 ;;;###autoload (define-key ctl-x-map "`" 'next-error)
+
+(defalias 'goto-next-locus 'next-error)
+(defalias 'next-match 'next-error)
 
 (defun previous-error (argp)
   "Visit previous compilation error message and corresponding source code.
